const Encore = require('@symfony/webpack-encore');

// Manually configure the runtime environment if not already configured yet by the "encore" command.
// It's useful when you use tools that rely on webpack.config.js file.
if (!Encore.isRuntimeEnvironmentConfigured()) {
    Encore.configureRuntimeEnvironment(process.env.NODE_ENV || 'dev');
}

const path = require('path');

Encore
    // directory where compiled assets will be stored
    .setOutputPath('public/build/')
    // public path used by the web server to access the output path
    .setPublicPath('/build')
    // only needed for CDN's or sub-directory deploy
    //.setManifestKeyPrefix('build/')
    .enableSassLoader()
    .addAliases({
        'core-js': path.resolve(__dirname, './node_modules/core-js'),
        'jquery': path.join(__dirname, 'node_modules/jquery/src/jquery'),
        'adminlte-js': path.resolve(__dirname, 'node_modules/admin-lte/dist/js/adminlte.min.js'),
        'adminlte-css': path.resolve(__dirname, 'node_modules/admin-lte/dist/css/adminlte.min.css'),
        'fontawesome-css': path.resolve(__dirname, 'node_modules/admin-lte/plugins/fontawesome-free/css/all.css'),
        'adminlte-plugin': path.resolve(__dirname, './node_modules/admin-lte/plugins/'),

        /*'adminlte': path.resolve(__dirname, './node_modules/admin-lte/dist/js/adminlte.min.js'),
        'adminltePlugin': path.resolve(__dirname, './node_modules/admin-lte/plugins/'),
        'admin-lte-css': path.resolve(__dirname, './node_modules/admin-lte/dist/css/adminlte.css'),
        'core-js': path.resolve(__dirname, './node_modules/core-js'),
        'jquery': path.join(__dirname, 'node_modules/jquery/src/jquery'),
        'select2': path.join(__dirname, 'node_modules/select2/dist/js/select2.js'),
        'select2-css': path.join(__dirname, 'node_modules/select2/dist/css/select2.min.css'),*/
        //'select2-bootstrap-theme': path.join(__dirname, 'node_modules/select2-bootstrap-5-theme/dist/select2-bootstrap-5-theme.min.css')
    })

    /*
     * ENTRY CONFIG
     *
     * Each entry will result in one JavaScript file (e.g. app.js)
     * and one CSS file (e.g. app.css) if your JavaScript imports CSS.
     */
    //.addEntry('backend-common', './assets/apps/backend/common/app.common.js')
    //.addEntry('jquery', './node_modules/jquery/dist/jquery.slim.js')
    .addEntry('backend-common', './Lc/SovBundle/Resources/assets/apps/backend-common/app.common.js')
    .addEntry('form', './Lc/SovBundle/Resources/assets/apps/form/app.form.js')
    .addEntry('field-filemanager', './Lc/SovBundle/Resources/assets/fields/filemanager/app.field-filemanager.js')
    //.addEntry('tabler', './Lc/SovBundle/Resources/assets/apps/tabler/app.tabler.js')
    //.addEntry('easyadmin', './vendor/easycorp/easyadmin-bundle/assets/js/app.js')

    // enables the Symfony UX Stimulus bridge (used in assets/bootstrap.js)
    .enableStimulusBridge('./assets/controllers.json')

    // When enabled, Webpack "splits" your files into smaller pieces for greater optimization.
    .splitEntryChunks()

    // will require an extra script tag for runtime.js
    // but, you probably want this, unless you're building a single-page app
    .enableSingleRuntimeChunk()

    /*
     * FEATURE CONFIG
     *
     * Enable & configure other features below. For a full
     * list of features, see:
     * https://symfony.com/doc/current/frontend.html#adding-more-features
     */
    .cleanupOutputBeforeBuild()
    .enableBuildNotifications()
    .enableSourceMaps(!Encore.isProduction())
    // enables hashed filenames (e.g. app.abc123.css)
    .enableVersioning(Encore.isProduction())

    .configureBabel((config) => {
        config.plugins.push('@babel/plugin-proposal-class-properties');
    })

    // enables @babel/preset-env polyfills
    .configureBabelPresetEnv((config) => {
        config.useBuiltIns = 'usage';
        config.corejs = 3;
    })


// enables Sass/SCSS support
//.enableSassLoader()

// uncomment if you use TypeScript
//.enableTypeScriptLoader()

// uncomment if you use React
//.enableReactPreset()

// uncomment to get integrity="..." attributes on your script & link tags
// requires WebpackEncoreBundle 1.4 or higher
//.enableIntegrityHashes(Encore.isProduction())

// uncomment if you're having problems with a jQuery plugin
//.autoProvidejQuery()
;

module.exports = Encore.getWebpackConfig();
